Package 'lintools'
| Title: |
Manipulation of Linear Systems of (in)Equalities |
| Description: |
Variable elimination (Gaussian elimination,
Fourier-Motzkin elimination), Moore-Penrose pseudoinverse,
reduction to reduced row echelon form, value substitution,
projecting a vector on the convex polytope described by a
system of (in)equations, simplify systems by removing spurious
columns and rows and collapse implied equalities, test if a
matrix is totally unimodular, compute variable ranges implied
by linear (in)equalities. |
| Authors: |
Mark van der Loo [aut, cre],
Edwin de Jonge [aut] |
| Maintainer: |
Mark van der Loo <[email protected]> |
| License: |
GPL-3 |
| Version: |
0.1.7.1 |
| Built: |
2026-05-31 10:17:44 UTC |
| Source: |
https://github.com/data-cleaning/lintools |
Help Index